==> haskell-transformers-base-0.4.6-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 transformers-base
version:              0.4.6
visibility:           public
id:                   transformers-base-0.4.6-8PLbLN0z4cRFaAru9ySoP6
key:                  transformers-base-0.4.6-8PLbLN0z4cRFaAru9ySoP6
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  5f36b3a34ea8e01fd10e19036f830ea4
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-9.4.8/site-local/transformers-base-0.4.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/transformers-base-0.4.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/transformers-base-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-base
hs-libraries:         HStransformers-base-0.4.6-8PLbLN0z4cRFaAru9ySoP6
depends:
    base-4.17.2.1 base-orphans-0.9.2-2EhyYySTciO7K9XI75C24v stm-2.5.1.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.6-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 transformers-base
version:              0.4.6
visibility:           public
id:                   transformers-base-0.4.6-ChRW239HasyDHet7IIm2Fi
key:                  transformers-base-0.4.6-ChRW239HasyDHet7IIm2Fi
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  1e151a2ebb4bf97af0ce84562053c596
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-9.4.8/site-local/transformers-base-0.4.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/transformers-base-0.4.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/transformers-base-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-base
hs-libraries:         HStransformers-base-0.4.6-ChRW239HasyDHet7IIm2Fi
depends:
    base-4.17.2.1 base-orphans-0.9.2-2oY2xi7DU11JX3N05E11iU stm-2.5.1.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
